@@ -181,8 +181,8 @@ class SQLEnumerable:
 
         # From now on we recover fquerys and MagicDotPath to do test on it.
 
-        self_fquery = self_select.args.fquery  # type: ignore
-        sqle_fquery = sqle_select.args.fquery  # type: ignore
+        self_fquery = self_select.args.fquery  # type: ignore[union-attr]
+        sqle_fquery = sqle_select.args.fquery  # type: ignore[union-attr]
 
         mdp_self = self_fquery(MagicDotPath(self.connection)) if self_fquery else "all"
         mdp_sqle = sqle_fquery(MagicDotPath(sqle.connection)) if sqle_fquery else "all"
@@ -279,23 +279,23 @@ class SQLEnumerable:
                 if self.flags.alter:
                     cmd = cast(Ct, cmd)  # HACK
                     raise AlterError(cmd.value)
-            case (Ct.INSERT | Ct.ALL | Ct.ANY | Ct.CONTAINS):  # noqa: E211
+            case (Ct.INSERT | Ct.ALL | Ct.ANY | Ct.CONTAINS):
                 if self.cmd:
                     cmd = cast(Ct, cmd)  # HACK
                     raise MoreThanZeroError(cmd.value)
-            case (Ct.UPDATE | Ct.DELETE):  # noqa: E211
+            case (Ct.UPDATE | Ct.DELETE):
                 if not self._only_where_command():
                     raise OtherThanWhereError()
             case Ct.WHERE:
                 if self.flags.terminal:
                     cmd = cast(Ct, cmd)  # HACK
                     raise TerminalError(cmd.value)
-            case (Ct.MAX | Ct.MIN):  # noqa: E211
+            case (Ct.MAX | Ct.MIN):
                 self._check_legality_terminal_alter(cmd)
                 if self.flags.limit_offset:
                     cmd = cast(Ct, cmd)  # HACK
                     raise NoMaxOrMinAfterLimitOffsetError(cmd.value)
-            case (Ct.INTERSECT | Ct.UNION):  # noqa: E211
+            case (Ct.INTERSECT | Ct.UNION):
                 if not self.flags.select:
                     cmd = cast(Ct, cmd)  # HACK
                     raise NeedSelectError(cmd.value)
@@ -1631,12 +1631,12 @@ class SQLEnumerable:
                 self.flags.default_cmd,
                 self.flags.terminal,
                 self.flags.limit_offset,
-            ):  # noqa: E211
-                case (True, _, _):  # noqa: E211
+            ):
+                case (True, _, _):
                     return None
-                case (False, Terminal.ELEMENT_AT, _):  # noqa: E211
+                case (False, Terminal.ELEMENT_AT, _):
                     raise IndexError() from ReturnEmptyEnumerable
-                case (_, _, True):  # noqa: E211
+                case (_, _, True):
                     return Enumerable.empty()
                 case _:
                     # pylint disable=duplicate-code
