@@ -21,14 +21,17 @@ from .op_and_func_of_mdp import (
     HyperBFuncType,
     MathFunctType,
     OperatorType,
+    StrFunctType,
     TrigoFunctType,
     col_name_hyper,
     col_name_math,
     col_name_ope,
+    col_name_str,
     col_name_trigo,
     json_path_hyper,
     json_path_math,
     json_path_ope,
+    json_path_str,
     json_path_trigo,
 )
 
@@ -46,8 +49,9 @@ else:
 
 
 _OTHER_TYPE = float | int | str | list | dict | Decimal
-_OPERATORTYPE = HyperBFuncType | MathFunctType | OperatorType | TrigoFunctType
-
+_OPERATORTYPE = (
+    HyperBFuncType | MathFunctType | OperatorType | TrigoFunctType | StrFunctType
+)
 # ---------------
 # |  Functions  |
 # ---------------
@@ -288,7 +292,10 @@ class BaseMagicDotPath:
         """
         return self._get_number_operator(other, OperatorType.LE)
 
-    def __eq__(self, other: _OTHER_TYPE) -> MagicDotPathWithOp:  # type: ignore
+    def __eq__(  # type: ignore[override]
+        self,
+        other: _OTHER_TYPE,
+    ) -> MagicDotPathWithOp:
         """
         Get a MagicDotPathWithOp objects with a `=` operator and the correct types.
 
@@ -305,7 +312,10 @@ class BaseMagicDotPath:
         """
         return self._get_generic_operator(other, OperatorType.EQ)
 
-    def __ne__(self, other: _OTHER_TYPE) -> MagicDotPathWithOp:  # type: ignore
+    def __ne__(  # type: ignore[override]
+        self,
+        other: _OTHER_TYPE,
+    ) -> MagicDotPathWithOp:
         """
         Get a MagicDotPathWithOp objects with a `<>` operator and the correct types.
 
@@ -878,6 +888,8 @@ class MagicDotPathWithOp(BaseMagicDotPath):
                 result = json_path_math(path_op, self.operator)
             case type() if isinstance(self.operator, TrigoFunctType):
                 result = json_path_trigo(path_op, self.operator)
+            case type() if isinstance(self.operator, StrFunctType):
+                result = json_path_str(path_op, self.operator)
             case type() if self.my_type == BaseMagicDotPath:
                 result = (
                     f"CAST({path_op.op1} AS decimal) "
@@ -932,6 +944,8 @@ class MagicDotPathWithOp(BaseMagicDotPath):
                 result = col_name_ope(name_op, operator)
             case operator if operator in TrigoFunctType:
                 result = col_name_trigo(name_op, operator)
+            case operator if operator in StrFunctType:
+                result = col_name_str(name_op, operator)
             # No cover because is just an other security,
             # but we can't go in this case thanks to Enum.
             case _:  # pragma: no cover
